A R6 class wrapper for data.table
A R6 class wrapper for data.table
DTdata.table of k-mers
new()initialize empty data.table of k-mers
Kmer_Table$new()
remove_N()Remove unknown base N.
Kmer_Table$remove_N()
filter_central_pattern()Filter out k-mers without defined central patterns.
Kmer_Table$filter_central_pattern(central.pattern, k)central.patternCentral pattern.
kLength of k-mer.
None.
update_count()Update count for existed k-mers in the table.
Kmer_Table$update_count(kmers, is.strand.sensitive, strand)kmersK-mer table with new count to be added to the main table.
is.strand.sensitiveDoes strand polarity matter?
strandIf yes, what is the strand refers to? "+" or "-".
None.
update_row()Add new rows for new k-mers with their respective counts that is not existed yet in the main table.
Kmer_Table$update_row(kmers, is.strand.sensitive, strand)kmersK-mer table with new k-mers to be added to the main table.
is.strand.sensitiveDoes strand polarity matter?
strandIf yes, what is the strand refers to? "+" or "-".
None.
clone()The objects of this class are cloneable with this method.
Kmer_Table$clone(deep = FALSE)deepWhether to make a deep clone.
A way to grow data.table in different environment but still retaining access to it. A temporary fix until data.table developer develop update row by reference.