Class constructor - build NCBI Genome object
Class constructor - build NCBI Genome object
fasta_fileA path to FASTA file. fasta files.
genome_nameA genome name.
dbNCBI database: "refseq" or "genbank"
seqA chromosome-named list of sequences.
seq_lenA chromosome-named vector of sequence length.
load_limitMaximum chromosome sequences loaded.
maskGenome mask status: "hard", "soft", or "none".
use_UCSC_nameUse UCSC style chromosome name? Default to FALSE.
headersA chromosome-named vector of headers.
avail_seqsAvailable chromosome sequences in the fasta file.
asmAssembly summary.
new()Create a new NCBI Genome class
NCBI_Genome$new(
genome.name,
db,
fasta.file,
asm,
mask,
use.UCSC.name,
load.limit
)genome.nameA genome name. NCBI genome is included with kmeRtone.
dbNCBI database: "refseq" or "genbank".
fasta.fileA path to the NCBI-style fasta files. This is for user's own FASTA file.
asmNCBI assembly summary.
maskGenome mask status: "hard", "soft", or "none". Default is "none".
use.UCSC.nameUse UCSC style chromosome name? Default to FALSE.
load.limitMaximum chromosome sequences loaded. Default is 1.
A new NCBI Genome object.
[()Calling chromosome sequence by loading on demand. Maximum load is determine by load_limit field.
NCBI_Genome$[(chr.names, reload = FALSE)chr.namesChromosome name. It can be a vector of chromosomes.
reloadReload the sequence from the fasta_file. Default is FALSE.
A single or list of sequence of requested chromosome.
Message of Genome object summary.
get_assembly_report()Get NCBI assembly report for the genome.
NCBI_Genome$get_assembly_report()Message of Genome object summary.
clone()The objects of this class are cloneable with this method.
NCBI_Genome$clone(deep = FALSE)deepWhether to make a deep clone.
NCBI FASTA file contain nucleotide accession number at the headers, followed by some information about the sequence whether they are chromosome, plasmid, or mictochondria, their assembly status, etc.