Class constructor - build Genome object
Class constructor - build Genome object
root_pathA path to a directory containing chromosome-separated fasta files.
genome_nameA genome name.
pathsIndividual chromosome sequence files.
seqA chromosome-named list of sequences.
seq_lenA chromosome-named vector of sequence length.
load_limitMaximum chromosome sequences loaded.
maskGenome mask status: "hard", "soft", or "none".
info_filePath to info file with pre-computed values.
chr_namesChromosome names.
new()Create a new Genome class
UCSC_Genome$new(genome.name, root.path, mask, load.limit)genome.nameA genome name. UCSC genome is included with kmeRtone.
root.pathPath to a directory of user-provided genome FASTA files or the destination to save the NCBI/UCSC downloaded reference genome files.
maskGenome mask status: "hard", "soft", or "none". Default is "none".
load.limitMaximum chromosome sequences loaded. Default is 1.
A new Genome object.
[()Calling chromosome sequence by loading on demand. Maximum load is determine by load_limit field.
UCSC_Genome$[(chr.names, reload = FALSE)chr.namesChromosome name. It can be a vector of chromosomes.
reloadReload the sequence from the root_path. Default is FALSE.
A single or list of sequence of requested chromosome.
Message of Genome object summary.
get_length()Get chromosome length from pre-calculated length
UCSC_Genome$get_length(chr.names, recalculate = FALSE)chr.namesChromosome name. It can be a vector of chromosomes.
recalculateRecalculate the pre-calculated length.
A chromosome-named vector of length value.
get_content()Get pre-calculated sequence content e.g. G+C content
UCSC_Genome$get_content(chr.names, seq, recalculate = FALSE)chr.namesChromosome name. It can be a vector of chromosomes.
seqSequence to count. e.g. c("G", "C")
recalculateRecalculate the pre-calculated length.
A chromosome-named vector of sequence content.
clone()The objects of this class are cloneable with this method.
UCSC_Genome$clone(deep = FALSE)deepWhether to make a deep clone.